@@ -15,8 +15,8 @@ from six.moves.urllib.error import HTTPError
 from six.moves import map
 # Required for Windows
 import colorama
-colorama.init()
 
+DEFAULT_REMOTE = "https://raw.github.com/tldr-pages/tldr/master/pages"
 USE_CACHE = int(os.environ.get('TLDR_CACHE_ENABLED', '1')) > 0
 MAX_CACHE_AGE = int(os.environ.get('TLDR_CACHE_MAX_AGE', 24))
 
@@ -62,8 +62,6 @@ def get_terminal_size():
 # get terminal size
 rows, columns = get_terminal_size()
 
-remote = "https://raw.github.com/tldr-pages/tldr/master/pages"
-
 os_directories = {
     "linux": "linux",
     "darwin": "osx",
@@ -127,12 +125,18 @@ def have_recent_cache(command, platform):
         return False
 
 
-def get_page_for_platform(command, platform):
+def get_page_url(platform, command, remote=None):
+    if remote is None:
+        remote = DEFAULT_REMOTE
+    return remote + "/" + platform + "/" + quote(command) + ".md"
+
+
+def get_page_for_platform(command, platform, remote=None):
     data_downloaded = False
     if USE_CACHE and have_recent_cache(command, platform):
         data = load_page_from_cache(command, platform)
     else:
-        page_url = remote + "/" + platform + "/" + quote(command) + ".md"
+        page_url = get_page_url(platform, command, remote)
         try:
             data = urlopen(page_url).read()
             data_downloaded = True
@@ -145,8 +149,8 @@ def get_page_for_platform(command, platform):
     return data.splitlines()
 
 
-def download_and_store_page_for_platform(command, platform):
-    page_url = remote + "/" + platform + "/" + quote(command) + ".md"
+def download_and_store_page_for_platform(command, platform, remote=None):
+    page_url = get_page_url(platform, command, remote)
     data = urlopen(page_url).read()
     store_page_to_cache(data, command, platform)
 
@@ -157,19 +161,19 @@ def get_platform():
             return os_directories[key]
 
 
-def get_page(command, platform=None):
+def get_page(command, remote=None, platform=None):
     if platform is None:
         platform = ["common", get_platform()]
-
     for _platform in platform:
+        if _platform is None:
+            continue
         try:
-            return get_page_for_platform(command, _platform)
+            return get_page_for_platform(command, _platform, remote=remote)
         except HTTPError as e:
             if e.code != 404:
                 raise
 
-    print(command + " documentation is not available\n"
-          "Consider contributing Pull Request to https://github.com/tldr-pages/tldr")
+    return False
 
 
 DEFAULT_COLORS = {
@@ -240,7 +244,7 @@ def output(page):
         [cprint(''.ljust(columns), *colors_of('blank')) for i in range(3)]
 
 
-def update_cache():
+def update_cache(remote=None):
     cache_path = get_cache_dir()
     if not os.path.exists(cache_path):
         return
@@ -252,10 +256,10 @@ def update_cache():
         command = match.group('command')
         platform = match.group('platform')
         try:
-            download_and_store_page_for_platform(command, platform)
-            print('Updated cache for %s (%s)' % (command, platform))
+            download_and_store_page_for_platform(command, platform, remote=remote)
+            print('Updated cache for %s (%s) from %s' % (command, platform, remote))
         except Exception:
-            print('Error: Unable to get %s (%s)' % (command, platform))
+            print('Error: Unable to get %s (%s) from %s' % (command, platform, remote))
 
 
 
@@ -273,25 +277,46 @@ def main():
                         choices=['linux', 'osx', 'sunos'],
                         help="Override the operating system [linux, osx, sunos]")
 
-    options, other_options = parser.parse_known_args()
+    parser.add_argument('-s', '--source',
+                        default=DEFAULT_REMOTE,
+                        type=str,
+                        help="Override the default page source")
+
+    parser.add_argument('-c', '--color',
+                        default=None,
+                        action='store_const',
+                        const=False,
+                        help="Override color stripping")
+
+    options, rest = parser.parse_known_args()
+
+    colorama.init(strip=options.color)
 
     if options.update_cache:
-        update_cache()
+        update_cache(remote=options.source)
         return
 
     parser.add_argument(
         'command', type=str, nargs='+', help="command to lookup")
 
-    options = parser.parse_args(other_options)
+    rest = parser.parse_args(rest)
 
-    for command in options.command:
-        try:
-            if options.os is not None:
-                output(get_page(command, options.os))
-            else:
-                output(get_page(command))
-        except Exception:
-            print("No internet connection detected. Please reconnect and try again.")
+    try:
+        result = get_page('-'.join(rest.command), platform=options.os, remote=options.source)
+        if not result:
+            for command in rest.command:
+                result = get_page(command, platform=options.os, remote=options.source)
+                if not result:
+                    print((
+                        "`{cmd}` documentation is not available. "
+                        "Consider contributing Pull Request to https://github.com/tldr-pages/tldr"
+                    ).format(cmd=command))
+                else:
+                    output(result)
+        else:
+            output(result)
+    except Exception:
+        print("No internet connection detected. Please reconnect and try again.")
 
 
 if __name__ == "__main__":
